@@ -6,7 +6,7 @@ from fastapi.responses import RedirectResponse, JSONResponse
 from sovereign import html_templates, discovery, XDS_TEMPLATES
 from sovereign.discovery import DiscoveryTypes
 from sovereign import json_response_class
-from sovereign.sources import available_service_clusters, _metadata
+from sovereign.sources import available_service_clusters, source_metadata
 from sovereign.utils.mock import mock_discovery_request
 
 router = APIRouter()
@@ -15,8 +15,20 @@ all_types = [t.value for t in DiscoveryTypes]
 
 
 @router.get('/', summary='Redirect to resource interface')
-async def ui_main():
-    return RedirectResponse(url=f'/ui/resources/{all_types[0]}')
+async def ui_main(request: Request):
+    try:
+        return RedirectResponse(url=f'/ui/resources/{all_types[0]}')
+    except IndexError:
+        return html_templates.TemplateResponse(
+            name='err.html',
+            media_type='text/html',
+            context={
+                'request': request,
+                'title': 'No resource types configured',
+                'message': 'A template should be defined for every resource '
+                           'type that you want your envoy proxies to discover.',
+                'doc_link': 'https://vsyrakis.bitbucket.io/sovereign/docs/tutorial/templates/',
+            })
 
 
 @router.get(
@@ -86,7 +98,7 @@ async def resources(
             'available_versions': list(XDS_TEMPLATES.keys()),
             'service_cluster': service_cluster,
             'available_service_clusters': available_service_clusters(),
-            'last_update': str(_metadata),
+            'last_update': str(source_metadata),
         })
 
 
